@@ -1,7 +1,7 @@
 import pandas as pd
 import pytest
 from .drivers.browsers import browser_os_name_conf
-from ..python_selenium_ctrl_package.conf.rwd.Website import base_url_conf
+from .conf.rwd.Website import base_url_conf
 
 
 @pytest.fixture
